From 414ddbe148ec845a2c9ced9bec15e1df8d56d602 Mon Sep 17 00:00:00 2001
From: "Reece R. Pollack" <reece.pollack@linaro.org>
Date: Wed, 13 Feb 2013 07:53:21 +0000
Subject: [PATCH] Samsung/Arndale: fix RELEASE build with ARMLINUXGCC

ARMLINUXGCC RELEASE builds have more errors as warnings than debug builds, causing release builds to fail.

This patch fixes the build failures by removing several uninitialised and/or unused variables.

Signed-off-by: Ryan Harkin <ryan.harkin@linaro.org>
---
 .../Exynos5250/Drivers/DisplayDxe/DisplayDxe.c     |    3 +--
 .../Exynos5250/Drivers/SDHCDxe_EVT1/SDHCDxe.c      |    9 +++++----
 .../ExynosPkg/Exynos5250/Drivers/eMMCDxe/eMMCDxe.c |    6 +++---
 3 files changed, 9 insertions(+), 9 deletions(-)

diff --git a/SamsungPlatformPkg/ExynosPkg/Exynos5250/Drivers/DisplayDxe/DisplayDxe.c b/SamsungPlatformPkg/ExynosPkg/Exynos5250/Drivers/DisplayDxe/DisplayDxe.c
index b9029c4..d1b5a3b 100644
--- a/SamsungPlatformPkg/ExynosPkg/Exynos5250/Drivers/DisplayDxe/DisplayDxe.c
+++ b/SamsungPlatformPkg/ExynosPkg/Exynos5250/Drivers/DisplayDxe/DisplayDxe.c
@@ -529,7 +529,6 @@ DisplayBlt(
   IN  UINTN                                   Delta         OPTIONAL
   )
 {
-  EFI_STATUS Status=EFI_SUCCESS;
   UINT8 *VidBuf, *BltBuf, *VidBuf1;
   UINTN i, j;
 
@@ -604,7 +603,7 @@ DisplayBlt(
       break;
 
     default:
-      ASSERT_EFI_ERROR(Status);
+      ASSERT_EFI_ERROR(EFI_SUCCESS);
   }
 
   return EFI_SUCCESS;
diff --git a/SamsungPlatformPkg/ExynosPkg/Exynos5250/Drivers/SDHCDxe_EVT1/SDHCDxe.c b/SamsungPlatformPkg/ExynosPkg/Exynos5250/Drivers/SDHCDxe_EVT1/SDHCDxe.c
index 70dbae1..0c3a219 100755
--- a/SamsungPlatformPkg/ExynosPkg/Exynos5250/Drivers/SDHCDxe_EVT1/SDHCDxe.c
+++ b/SamsungPlatformPkg/ExynosPkg/Exynos5250/Drivers/SDHCDxe_EVT1/SDHCDxe.c
@@ -118,7 +118,7 @@ MSHC_SendCmd (
   UINTN CmdArgument
   )
 {
-  UINTN MmcStatus;
+  UINTN MmcStatus = 0;
   volatile UINTN RetryCount = 0;
   int cmd_flags = 0;
   int timeout=0;
@@ -246,13 +246,14 @@ static const UINT8 MultiFactor[16]={0, 10, 12, 13, 15, 20, 26, 30, 35, 40, 45, 5
 
 void PrintCardInfo()
 {
+#if !defined(MDEPKG_NDEBUG)
     UINT8 TransSpeed = gCardInfo.CSDData.TRAN_SPEED;
     
     DEBUG ((EFI_D_INFO, "SDHC::READ_BL_LEN %d\n", gCardInfo.CSDData.READ_BL_LEN));     
     DEBUG ((EFI_D_INFO, "SDHC::CSize %d\n", gCardInfo.CSDData.C_SIZELow2 | (gCardInfo.CSDData.C_SIZEHigh10 << 2)));         
     DEBUG ((EFI_D_INFO, "SDHC::MULTI %d\n", gCardInfo.CSDData.C_SIZE_MULT));         
     DEBUG ((EFI_D_INFO, "SDHC::Speed %d\n", (FreqUnit[TransSpeed&0x7]*MultiFactor[TransSpeed>>3])));         
-
+#endif
 }
 
 
@@ -599,7 +600,7 @@ ReadBlockData (
   IN  UINTN                         BlockCount
   )
 {
-  EFI_STATUS Status;
+  EFI_STATUS Status = EFI_INVALID_PARAMETER;
   UINTN DataSize = This->Media->BlockSize/4;
 
   DEBUG ((EFI_D_INFO, "SDHC::ReadBlockData start \n"));
@@ -625,7 +626,7 @@ WriteBlockData (
   IN  UINTN                         BlockCount  
   )
 {
-    EFI_STATUS Status;
+    EFI_STATUS Status = EFI_INVALID_PARAMETER;
     UINTN DataSize = This->Media->BlockSize/4;
 
     if(MSHC_operation_mode == MSHC_FIFO)
diff --git a/SamsungPlatformPkg/ExynosPkg/Exynos5250/Drivers/eMMCDxe/eMMCDxe.c b/SamsungPlatformPkg/ExynosPkg/Exynos5250/Drivers/eMMCDxe/eMMCDxe.c
index c38001a..d166f66 100755
--- a/SamsungPlatformPkg/ExynosPkg/Exynos5250/Drivers/eMMCDxe/eMMCDxe.c
+++ b/SamsungPlatformPkg/ExynosPkg/Exynos5250/Drivers/eMMCDxe/eMMCDxe.c
@@ -123,7 +123,7 @@ MSHC_SendCmd (
   UINTN CmdArgument
   )
 {
-  UINTN MmcStatus;
+  UINTN MmcStatus = 0;
   volatile UINTN RetryCount = 0;
   int cmd_flags = 0;
   int timeout=0;
@@ -580,7 +580,7 @@ ReadBlockData (
   IN  UINTN                         BlockCount
   )
 {
-  EFI_STATUS Status;
+  EFI_STATUS Status = EFI_INVALID_PARAMETER;
   UINTN DataSize = This->Media->BlockSize/4;
 
   DEBUG ((EFI_D_INFO, "MSHC::ReadBlockData start \n"));
@@ -606,7 +606,7 @@ WriteBlockData (
   IN  UINTN                         BlockCount  
   )
 {
-    EFI_STATUS Status;
+    EFI_STATUS Status = EFI_INVALID_PARAMETER;
     UINTN DataSize = This->Media->BlockSize/4;
 
     if(MSHC_operation_mode == MSHC_FIFO)
-- 
1.7.9.5

